<?php
  /* vim: set expandtab tabstop=4 softtabstop=4 shiftwidth=4:
  Codificación: UTF-8
  +----------------------------------------------------------------------+
  | Elastix version 2.4.0-12                                               |
  | http://www.elastix.org                                               |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006 Palosanto Solutions S. A.                         |
  +----------------------------------------------------------------------+
  | Cdla. Nueva Kennedy Calle E 222 y 9na. Este                          |
  | Telfs. 2283-268, 2294-440, 2284-356                                  |
  | Guayaquil - Ecuador                                                  |
  | http://www.palosanto.com                                             |
  +----------------------------------------------------------------------+
  | The contents of this file are subject to the General Public License  |
  | (GPL) Version 2 (the "License"); you may not use this file except in |
  | compliance with the License. You may obtain a copy of the License at |
  | http://www.opensource.org/licenses/gpl-license.php                   |
  |                                                                      |
  | Software distributed under the License is distributed on an "AS IS"  |
  | basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See  |
  | the License for the specific language governing rights and           |
  | limitations under the License.                                       |
  +----------------------------------------------------------------------+
  | The Original Code is: Elastix Open Source.                           |
  | The Initial Developer of the Original Code is PaloSanto Solutions    |
  +----------------------------------------------------------------------+
  $Id: index.php,v 1.1 2014-11-28 12:11:14 Vladislav Yurov info@elastix.club Exp $ */
//include elastix framework
include_once "libs/paloSantoGrid.class.php";
include_once "libs/paloSantoForm.class.php";

function _moduleContent(&$smarty, $module_name)
{
    //include module files
    include_once "modules/$module_name/configs/default.conf.php";
    include_once "modules/$module_name/libs/paloSantoVoice_Manager.class.php";

    //include file language agree to elastix configuration
    //if file language not exists, then include language by default (en)
    $lang=get_language();
    $base_dir=dirname($_SERVER['SCRIPT_FILENAME']);
    $lang_file="modules/$module_name/lang/$lang.lang";
    if (file_exists("$base_dir/$lang_file")) include_once "$lang_file";
    else include_once "modules/$module_name/lang/en.lang";

    //global variables
    global $arrConf;
    global $arrConfModule;
    global $arrLang;
    global $arrLangModule;
    $arrConf = array_merge($arrConf,$arrConfModule);
    $arrLang = array_merge($arrLang,$arrLangModule);

    //folder path for custom templates
    $templates_dir=(isset($arrConf['templates_dir']))?$arrConf['templates_dir']:'themes';
    $local_templates_dir="$base_dir/modules/$module_name/".$templates_dir.'/'.$arrConf['theme'];

    //conexion resource
    //$pDB = new paloDB($arrConf['dsn_conn_database']);
    $pDB = "";


    //actions
    $action = getAction();
    $content = "";

    switch($action){
        case "install":
            $content = saveNewVoice_Manager($smarty, $module_name, $local_templates_dir, $pDB, $arrConf);
            break;
        default: // view_form
            $content = viewFormVoice_Manager($smarty, $module_name, $local_templates_dir, $pDB, $arrConf);
            break;
    }
    return $content;
}

function viewFormVoice_Manager($smarty, $module_name, $local_templates_dir, &$pDB, $arrConf)
{
    $pVoice_Manager = new paloSantoVoice_Manager($pDB);
    $arrFormVoice_Manager = createFieldForm();
    $oForm = new paloForm($smarty,$arrFormVoice_Manager);

    //begin, Form data persistence to errors and other events.
    $_DATA  = $_POST;
    $action = getParameter("action");
    $id     = getParameter("id");
    $smarty->assign("ID", $id); //persistence id with input hidden in tpl

    if($action=="view")
        $oForm->setViewMode();
    else if($action=="view_edit" || getParameter("save_edit"))
        $oForm->setEditMode();
    //end, Form data persistence to errors and other events.

    if($action=="view" || $action=="view_edit"){ // the action is to view or view_edit.
        $dataVoice_Manager = $pVoice_Manager->getVoice_ManagerById($id);
        if(is_array($dataVoice_Manager) & count($dataVoice_Manager)>0)
            $_DATA = $dataVoice_Manager;
        else{
            $smarty->assign("mb_title", _tr("Error get Data"));
            $smarty->assign("mb_message", $pVoice_Manager->errMsg);
        }
    }

    $smarty->assign("INSTALL", _tr("Install"));
    $smarty->assign("EDIT", _tr("Edit"));
    $smarty->assign("CANCEL", _tr("Cancel"));
    $smarty->assign("REQUIRED_FIELD", _tr("Required field"));
    $smarty->assign("icon", "images/list.png");
    $smarty->assign("CODE", _tr("Code"));
    $smarty->assign("LANGUAGE", _tr("Language"));
    $smarty->assign("FOLDER", _tr("Folder"));
    $smarty->assign("INSTALLED", _tr("Installed Asterisk Voice Sounds"));

    /* List language folders */
    $snd_folders = runBash('find /var/lib/asterisk/sounds/*/ -mindepth 0 -maxdepth 0 -type d');
    sort($snd_folders);
    $all_lng = ArrayElastixLanguages();
    $alng = array();
    foreach($snd_folders as $fld) {
      $afld = explode('/',$fld.'///////');
      if (array_key_exists($afld[5],$all_lng)) {
        $alng[] = array('lng' => $afld[5], 'folder' => $fld, 'name' => $all_lng[$afld[5]]);
      }
    }
    $smarty->assign("alng", $alng);

    $htmlForm = $oForm->fetchForm("$local_templates_dir/form.tpl",_tr("Voice Manager"), $_DATA);
    $content = "<form  method='POST' style='margin-bottom:0;' action='?menu=$module_name'>".$htmlForm."</form>";

    return $content;
}

function ArrayElastixLanguages()
{
  return array(
    "tst" => "Test Sounds",
    "af" => "Afrikaans",
    "sq" => "Albanian",
    "am" => "Amharic",
    "ar" => "Arabic",
    "au" => "Australian",
    "hy" => "Armenian",
    "az" => "Azerbaijani",
    "eu" => "Basque",
    "be" => "Belarusian",
    "bn" => "Bengali",
    "bh" => "Bihari",
    "bs" => "Bosnian",
    "br" => "Breton",
    "bg" => "Bulgarian",
    "km" => "Cambodian",
    "ca" => "Catalan",
    "zh-CN" => "Chinese (Simplified)",
    "zh-TW" => "Chinese (Traditional)",
    "co" => "Corsican",
    "hr" => "Croatian",
    "cs" => "Czech",
    "da" => "Danish",
    "nl" => "Dutch",
    "en" => "English",
    "eo" => "Esperanto",
    "et" => "Estonian",
    "fo" => "Faroese",
    "tl" => "Filipino",
    "fi" => "Finnish",
    "fr" => "French",
    "fy" => "Frisian",
    "gl" => "Galician",
    "ka" => "Georgian",
    "de" => "German",
    "el" => "Greek",
    "gn" => "Guarani",
    "gu" => "Gujarati",
    "xx-hacker" => "Hacker",
    "ha" => "Hausa",
    "iw" => "Hebrew",
    "hi" => "Hindi",
    "hu" => "Hungarian",
    "is" => "Icelandic",
    "id" => "Indonesian",
    "ia" => "Interlingua",
    "ga" => "Irish",
    "it" => "Italian",
    "ja" => "Japanese",
    "jw" => "Javanese",
    "kn" => "Kannada",
    "kk" => "Kazakh",
    "rw" => "Kinyarwanda",
    "rn" => "Kirundi",
    "xx-klingon" => "Klingon",
    "ko" => "Korean",
    "ku" => "Kurdish",
    "ky" => "Kyrgyz",
    "lo" => "Laothian",
    "la" => "Latin",
    "lv" => "Latvian",
    "ln" => "Lingala",
    "lt" => "Lithuanian",
    "mk" => "Macedonian",
    "mg" => "Malagasy",
    "ms" => "Malay",
    "ml" => "Malayalam",
    "mt" => "Maltese",
    "mi" => "Maori",
    "mr" => "Marathi",
    "mo" => "Moldavian",
    "mn" => "Mongolian",
    "sr-ME" => "Montenegrin",
    "ne" => "Nepali",
    "no" => "Norwegian",
    "nn" => "Norwegian (Nynorsk)",
    "oc" => "Occitan",
    "or" => "Oriya",
    "om" => "Oromo",
    "ps" => "Pashto",
    "fa" => "Persian",
    "xx-pirate" => "Pirate",
    "pl" => "Polish",
    "pt-BR" => "Portuguese (Brazil)",
    "pt-PT" => "Portuguese (Portugal)",
    "pa" => "Punjabi",
    "qu" => "Quechua",
    "ro" => "Romanian",
    "rm" => "Romansh",
    "ru" => "Russian",
    "gd" => "Scots Gaelic",
    "sr" => "Serbian",
    "sh" => "Serbo-Croatian",
    "st" => "Sesotho",
    "sn" => "Shona",
    "sd" => "Sindhi",
    "si" => "Sinhalese",
    "sk" => "Slovak",
    "sl" => "Slovenian",
    "so" => "Somali",
    "es" => "Spanish",
    "su" => "Sundanese",
    "sw" => "Swahili",
    "sv" => "Swedish",
    "tg" => "Tajik",
    "ta" => "Tamil",
    "tt" => "Tatar",
    "te" => "Telugu",
    "th" => "Thai",
    "ti" => "Tigrinya",
    "to" => "Tonga",
    "tr" => "Turkish",
    "tk" => "Turkmen",
    "tw" => "Twi",
    "ug" => "Uighur",
    "uk" => "Ukrainian",
    "ur" => "Urdu",
    "uz" => "Uzbek",
    "vi" => "Vietnamese",
    "cy" => "Welsh",
    "xh" => "Xhosa",
    "yi" => "Yiddish",
    "yo" => "Yoruba",
    "zu" => "Zulu",
    
  );
}

function getInstallSoundsCMD($lng)
{
  $aSource = array(
    "ru" => array(
	"source" => "https://github.com/pbxware/asterisk-sounds/tarball/master",
	"saveto" => "/tmp/asterisk-sounds-ru.tar.gz",
	),
    "ru-github" => array(
	"source" => "https://github.com/pbxware/asterisk-sounds/archive/master.zip",
	"saveto" => "/tmp/asterisk-sounds-master.zip",
	),
    "ru-github-add" => array(
	"source" => "https://github.com/pbxware/asterisk-sounds-additional/archive/master.zip",
	"saveto" => "/tmp/asterisk-sounds-additional-master.zip",
	),
    "au" => array(
	"source" => "http://www.elastix.club/dist/OpenVoice-Free-2.0.tar.gz",
	"saveto" => "/tmp/asterisk-sounds-au.tar.gz",
	),
    );
    
  $aCMD = array(
    "ru" => 
       "cd /tmp;"
      ."tar xzvf asterisk-sounds-ru.tar.gz;"
      ."mv /var/lib/asterisk/sounds/ru /var/lib/asterisk/sounds/ru-orig;"
      ."mkdir /var/lib/asterisk/sounds/ru;"
      ."mv pbxware-asterisk-sounds-*/* /var/lib/asterisk/sounds/ru/;"
      ,
    "ru-github" => 
       "cd /tmp;"
      ."unzip asterisk-sounds-master.zip;"
      ."mv /var/lib/asterisk/sounds/ru /var/lib/asterisk/sounds/ru-orig;"
      ."mkdir /var/lib/asterisk/sounds/ru;"
      ."mv ./asterisk-sounds-master/* /var/lib/asterisk/sounds/ru/;"
      ,
    "ru-github-add" => 
       "cd /tmp;"
      ."unzip asterisk-sounds-additional-master.zip;"
      ."mkdir /var/lib/asterisk/sounds/ru;"
      ."mv ./asterisk-sounds-additional-master/* /var/lib/asterisk/sounds/ru/;"
      ,
    "au" => 
       "cd /tmp;"
      ."tar xzvf asterisk-sounds-au.tar.gz;"
      ."mv /var/lib/asterisk/sounds/au2 /var/lib/asterisk/sounds/au-orig;"
      ."mkdir /var/lib/asterisk/sounds/au;"
      ."mkdir /var/lib/asterisk/sounds/au/digits;"
      ."mv OpenVoice-Free-2.0/au/* /var/lib/asterisk/sounds/au/;"
      ."mv OpenVoice-Free-2.0/digits/au/* /var/lib/asterisk/sounds/au/digits/;"
      ,
  );
  if (array_key_exists($lng,$aCMD)) {
    download_file($aSource[$lng]['source'], $aSource[$lng]['saveto']);
    $resCMD = $aCMD[$lng];
  } else {
    $resCMD = '';
  }
  return $resCMD;
}

function download_file($src, $dest) {
    $data = file_get_contents($src);
    $file = fopen($dest, "w+");
    fputs($file, $data);
    fclose($file);
}

function saveNewVoice_Manager($smarty, $module_name, $local_templates_dir, &$pDB, $arrConf)
{
    $pVoice_Manager = new paloSantoVoice_Manager($pDB);
    $arrFormVoice_Manager = createFieldForm();
    $oForm = new paloForm($smarty,$arrFormVoice_Manager);

    if(!$oForm->validateForm($_POST)){
        // Validation basic, not empty and VALIDATION_TYPE 
        $smarty->assign("mb_title", _tr("Validation Error"));
        $arrErrores = $oForm->arrErroresValidacion;
        $strErrorMsg = "<b>"._tr("The following fields contain errors").":</b><br/>";
        if(is_array($arrErrores) && count($arrErrores) > 0){
            foreach($arrErrores as $k=>$v)
                $strErrorMsg .= "$k, ";
        }
        $smarty->assign("mb_message", $strErrorMsg);
        $content = viewFormVoice_Manager($smarty, $module_name, $local_templates_dir, $pDB, $arrConf);
    }
    else{
        //NO ERROR, HERE IMPLEMENTATION OF SAVE
        $slng = getParameter('install_voice_language');
        $cmdLng = getInstallSoundsCMD($slng);
//        var_dump( $cmdLng);
        if (!empty($cmdLng)) {
          $res = runBash($cmdLng);
//          var_dump($res);
        }
        $content = viewFormVoice_Manager($smarty, $module_name, $local_templates_dir, $pDB, $arrConf);
    }
    return $content;
}

function createFieldForm()
{
    $arrLanguages = array(
	'--' => _tr('Select Sounds Language to Install'), 
	'ru-github' => 'Russian (ru): by www.github.com. Main voice file', 
	'ru-github-add' => 'Russian (ru): by www.github.com. Additional voice file', 
	'ru' => 'Russian (ru): by www.ivrvoice.ru', 
	'au' => 'Australian (au): by www.openvoice.com.au', 
	);

    $arrFields = array(
            "install_voice_language"   => array(      "LABEL"                  => _tr("Asterisk Voice Language"),
                                            "REQUIRED"               => "no",
                                            "INPUT_TYPE"             => "SELECT",
                                            "INPUT_EXTRA_PARAM"      => $arrLanguages,
                                            "VALIDATION_TYPE"        => "text",
                                            "VALIDATION_EXTRA_PARAM" => "",
                                            "EDITABLE"               => "si",
                                            ),

            );
    return $arrFields;
}

function getAction()
{
    if(getParameter("install")) //Get parameter by POST (submit)
        return "install";
    else if(getParameter("save_edit"))
        return "save_edit";
    else if(getParameter("delete")) 
        return "delete";
    else if(getParameter("new_open")) 
        return "view_form";
    else if(getParameter("action")=="view")      //Get parameter by GET (command pattern, links)
        return "view_form";
    else if(getParameter("action")=="view_edit")
        return "view_form";
    else
        return "report"; //cancel
}


function runBash($cmd) {
    putenv("TERM=vt100");
    putenv("PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin");
    $badchars = array("'", "`", "\\", "\""); // Strip off any nasty chars.
    $fixedcmd = str_replace($badchars, "", $cmd);
    $ph = popen(stripslashes($fixedcmd), 'r');
    $res = '';
    while ($line = stream_get_line($ph,1024)) {
      $res .= htmlspecialchars($line);
    }
    pclose($ph); 
    return explode("\n",$res);
}
?>